==> fans-common-core-1.0.5-sources.jar: com/ptteng/sca/fans/common/client/ContentsSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.Contents;
import com.ptteng.fans.common.service.ContentsService;
import java.util.List;
import java.util.Map;

public class ContentsSCAClient implements ContentsService {

    private ContentsService contentsService;

	public ContentsService getContentsService() {
		return contentsService;
	}
	
	
	public void setContentsService(ContentsService contentsService) {
		this.contentsService =contentsService;
	}
	
	
			   
		@Override
		public Long insert(Contents contents)throws ServiceException, ServiceDaoException{
		
		return contentsService.insert(contents);
		          
		
		}	
		  
    	   
		@Override
		public List<Contents> insertList(List<Contents> contentsList)throws ServiceException, ServiceDaoException{
		
		return contentsService.insertList(contentsList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return contentsService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Contents contents)throws ServiceException, ServiceDaoException{
		
		return contentsService.update(contents);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Contents> contentsList)throws ServiceException, ServiceDaoException{
		
		return contentsService.updateList(contentsList);
		          
		
		}	
		  
    	   
		@Override
		public Contents getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return contentsService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Contents> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return contentsService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByMerchantId(Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByMerchantId(merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByType(Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByType(type,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByTypeAndMerchantIdOrderBySort(Integer type,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByTypeAndMerchantIdOrderBySort(type,merchantId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByMerchantId(merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByType(Integer type)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByType(type);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByTypeAndMerchantIdOrderBySort(Integer type,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByTypeAndMerchantIdOrderBySort(type,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getContentsIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.getContentsIds(start, limit);
	}

	@Override
	public Integer countContentsIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.countContentsIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   contentsService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.contentsService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> fans-common-core-1.1.3-sources.jar: com/ptteng/sca/fans/common/client/ContentsSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.Contents;
import com.ptteng.fans.common.service.ContentsService;
import java.util.List;
import java.util.Map;

public class ContentsSCAClient implements ContentsService {

    private ContentsService contentsService;

	public ContentsService getContentsService() {
		return contentsService;
	}
	
	
	public void setContentsService(ContentsService contentsService) {
		this.contentsService =contentsService;
	}
	
	
			   
		@Override
		public Long insert(Contents contents)throws ServiceException, ServiceDaoException{
		
		return contentsService.insert(contents);
		          
		
		}	
		  
    	   
		@Override
		public List<Contents> insertList(List<Contents> contentsList)throws ServiceException, ServiceDaoException{
		
		return contentsService.insertList(contentsList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return contentsService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Contents contents)throws ServiceException, ServiceDaoException{
		
		return contentsService.update(contents);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Contents> contentsList)throws ServiceException, ServiceDaoException{
		
		return contentsService.updateList(contentsList);
		          
		
		}	
		  
    	   
		@Override
		public Contents getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return contentsService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Contents> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return contentsService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByMerchantId(Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByMerchantId(merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByType(Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByType(type,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getContentsIdsByTypeAndMerchantIdOrderBySort(Integer type,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return contentsService.getContentsIdsByTypeAndMerchantIdOrderBySort(type,merchantId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByMerchantId(merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByType(Integer type)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByType(type);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countContentsIdsByTypeAndMerchantIdOrderBySort(Integer type,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return contentsService.countContentsIdsByTypeAndMerchantIdOrderBySort(type,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getContentsIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.getContentsIds(start, limit);
	}

	@Override
	public Integer countContentsIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.countContentsIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return contentsService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   contentsService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.contentsService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

    @Override
    public Object getMapListByDynamicCondition(Class clz,Map<String, Object> conditions, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return this.contentsService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
